# Machine Learning From Scratch 

## About

Practical implementations of common machine learning algorithms with test
cases coded from scratch in a similar style as Scikit-learn using 
Object-Oriented Programming.

This project is meant to increase our understanding of machine learning
algorithms and what is  'underneath the hood'. It is not meant for use
in actual data science work.  

## Installation
Create a virtual environment and run the following commands in your terminal.

```
    $ git clone https://github.com/lukenew2/mlscratch
    $ cd mlscratch
    $ python setup.py install
```
